@@ -67,53 +67,58 @@ push button</source>
     <message>
         <location filename="../../KvantumPreviewBase.ui" line="279"/>
         <source>Button Box</source>
-        <translation type="unfinished"></translation>
+        <translation>Knappeboks</translation>
     </message>
     <message>
         <location filename="../../KvantumPreviewBase.ui" line="361"/>
         <source>Tool buttons</source>
-        <translation type="unfinished"></translation>
+        <translation>Verktøyknapper</translation>
     </message>
     <message>
         <location filename="../../KvantumPreviewBase.ui" line="369"/>
         <location filename="../../KvantumPreviewBase.ui" line="446"/>
         <source>Simple toolbutton</source>
-        <translation type="unfinished"></translation>
+        <translation>Enkel verktøyknapp</translation>
     </message>
     <message>
         <location filename="../../KvantumPreviewBase.ui" line="453"/>
         <location filename="../../KvantumPreviewBase.ui" line="464"/>
         <source>Multi-line
 toolbutton</source>
-        <translation type="unfinished"></translation>
+        <translation>Verktøyknapp
+over flere linjer</translation>
     </message>
     <message>
         <location filename="../../KvantumPreviewBase.ui" line="472"/>
         <location filename="../../KvantumPreviewBase.ui" line="495"/>
         <source>Toggle toolbutton
 with an arrow</source>
-        <translation type="unfinished"></translation>
+        <translation>Vekslingsbar verktøyknapp
+med en pil</translation>
     </message>
     <message>
         <location filename="../../KvantumPreviewBase.ui" line="560"/>
         <location filename="../../KvantumPreviewBase.ui" line="584"/>
         <source>Toolbutton with 32px SVG icon
 and text below</source>
-        <translation type="unfinished"></translation>
+        <translation>Verktøyknapp med 32 px SVG-ikon
+og tekst nedenfor</translation>
     </message>
     <message>
         <location filename="../../KvantumPreviewBase.ui" line="605"/>
         <location filename="../../KvantumPreviewBase.ui" line="626"/>
         <source>Toolbutton with text below
 and arrow</source>
-        <translation type="unfinished"></translation>
+        <translation>Verktøylinje med tekst under
+og pil</translation>
     </message>
     <message>
         <location filename="../../KvantumPreviewBase.ui" line="644"/>
         <location filename="../../KvantumPreviewBase.ui" line="665"/>
         <source>Toolbutton with icon at the side
 and arrow</source>
-        <translation type="unfinished"></translation>
+        <translation>Verktøyknapp med et ikon på siden
+og pil</translation>
     </message>
     <message>
         <location filename="../../KvantumPreviewBase.ui" line="683"/>
@@ -121,14 +126,17 @@ and arrow</source>
         <source>Toggle toolbutton with icon,
 ordinary arrow
 and dropdown menu arrow</source>
-        <translation type="unfinished"></translation>
+        <translation>Vekslingsbar verktøykknapp med ikon,
+vanlig pil
+og rullegardinsmeny-pil</translation>
     </message>
     <message>
         <location filename="../../KvantumPreviewBase.ui" line="515"/>
         <location filename="../../KvantumPreviewBase.ui" line="539"/>
         <source>Toolbutton with 32px PNG icon
 beside text</source>
-        <translation type="unfinished"></translation>
+        <translation>Verktøyknapp med 32 px PNG-ikon
+ved siden av tekst</translation>
     </message>
     <message>
         <location filename="../../KvantumPreviewBase.ui" line="402"/>
@@ -141,12 +149,20 @@ height
 greater
 than
 width</source>
-        <translation type="unfinished"></translation>
+        <translation>Veksle
+verktøylinje
+knapp
+
+med
+høyde
+større
+enn
+bredde</translation>
     </message>
     <message>
         <location filename="../../KvantumPreviewBase.ui" line="791"/>
         <source>Auto-raise</source>
-        <translation type="unfinished"></translation>
+        <translation>Auto-hev</translation>
     </message>
     <message>
         <location filename="../../KvantumPreviewBase.ui" line="812"/>
@@ -359,27 +375,29 @@ check box</source>
     <message>
         <location filename="../../KvantumPreviewBase.ui" line="2139"/>
         <source>Header 1</source>
-        <translation type="unfinished"></translation>
+        <translation>Overskrift 1</translation>
     </message>
     <message>
         <location filename="../../KvantumPreviewBase.ui" line="2148"/>
         <source>Header 2</source>
-        <translation type="unfinished"></translation>
+        <translation>Overskrift 2</translation>
     </message>
     <message>
         <location filename="../../KvantumPreviewBase.ui" line="2156"/>
         <source>Header 3</source>
-        <translation type="unfinished"></translation>
+        <translation>Overskrift 3</translation>
     </message>
     <message>
         <location filename="../../KvantumPreviewBase.ui" line="2161"/>
+        <location filename="../../KvantumPreviewBase.ui" line="2259"/>
         <source>3rd Item</source>
-        <translation type="unfinished"></translation>
+        <translation>tredje element</translation>
     </message>
     <message>
         <location filename="../../KvantumPreviewBase.ui" line="2169"/>
+        <location filename="../../KvantumPreviewBase.ui" line="2247"/>
         <source>2nd Item</source>
-        <translation type="unfinished"></translation>
+        <translation>Andre element</translation>
     </message>
     <message>
         <location filename="../../KvantumPreviewBase.ui" line="2173"/>
@@ -395,8 +413,9 @@ check box</source>
     </message>
     <message>
         <location filename="../../KvantumPreviewBase.ui" line="2184"/>
+        <location filename="../../KvantumPreviewBase.ui" line="2232"/>
         <source>1st Item</source>
-        <translation type="unfinished"></translation>
+        <translation>Første element</translation>
     </message>
     <message>
         <location filename="../../KvantumPreviewBase.ui" line="2204"/>
@@ -404,242 +423,242 @@ check box</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../KvantumPreviewBase.ui" line="2462"/>
+        <location filename="../../KvantumPreviewBase.ui" line="2502"/>
         <source>Row 0</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../KvantumPreviewBase.ui" line="2467"/>
+        <location filename="../../KvantumPreviewBase.ui" line="2507"/>
         <source>Row 1</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../KvantumPreviewBase.ui" line="2472"/>
+        <location filename="../../KvantumPreviewBase.ui" line="2512"/>
         <source>Column 0</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">Kolonne 0</translation>
     </message>
     <message>
-        <location filename="../../KvantumPreviewBase.ui" line="2480"/>
+        <location filename="../../KvantumPreviewBase.ui" line="2520"/>
         <source>Column 1</source>
-        <translation type="unfinished"></translation>
+        <translation>Kolonne 1</translation>
     </message>
     <message>
-        <location filename="../../KvantumPreviewBase.ui" line="2485"/>
+        <location filename="../../KvantumPreviewBase.ui" line="2525"/>
         <source>0-0</source>
-        <translation type="unfinished"></translation>
+        <translation>0-0</translation>
     </message>
     <message>
-        <location filename="../../KvantumPreviewBase.ui" line="2493"/>
+        <location filename="../../KvantumPreviewBase.ui" line="2533"/>
         <source>0-1</source>
-        <translation type="unfinished"></translation>
+        <translation>0-1</translation>
     </message>
     <message>
-        <location filename="../../KvantumPreviewBase.ui" line="2501"/>
+        <location filename="../../KvantumPreviewBase.ui" line="2541"/>
         <source>1-0</source>
-        <translation type="unfinished"></translation>
+        <translation>1-0</translation>
     </message>
     <message>
-        <location filename="../../KvantumPreviewBase.ui" line="2509"/>
+        <location filename="../../KvantumPreviewBase.ui" line="2549"/>
         <source>1-1</source>
-        <translation type="unfinished"></translation>
+        <translation>1-1</translation>
     </message>
     <message>
         <location filename="../../KvantumPreviewBase.ui" line="2191"/>
         <location filename="../../KvantumPreviewBase.ui" line="2194"/>
         <source>Editable</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">Redigerbart</translation>
     </message>
     <message>
         <location filename="../../KvantumPreviewBase.ui" line="2221"/>
         <source>Non-Editable</source>
-        <translation type="unfinished"></translation>
+        <translation>Ikke redigerbart</translation>
     </message>
     <message>
-        <location filename="../../KvantumPreviewBase.ui" line="2229"/>
+        <location filename="../../KvantumPreviewBase.ui" line="2269"/>
         <source>Subwindow</source>
-        <translation type="unfinished"></translation>
+        <translation>Undervindu</translation>
     </message>
     <message>
-        <location filename="../../KvantumPreviewBase.ui" line="2276"/>
+        <location filename="../../KvantumPreviewBase.ui" line="2316"/>
         <source>Panel frame</source>
-        <translation type="unfinished"></translation>
+        <translation>Panelramme</translation>
     </message>
     <message>
-        <location filename="../../KvantumPreviewBase.ui" line="2295"/>
-        <location filename="../../KvantumPreviewBase.ui" line="2436"/>
-        <location filename="../../KvantumPreviewBase.ui" line="2528"/>
+        <location filename="../../KvantumPreviewBase.ui" line="2335"/>
+        <location filename="../../KvantumPreviewBase.ui" line="2476"/>
+        <location filename="../../KvantumPreviewBase.ui" line="2568"/>
         <source>GroupBox</source>
-        <translation type="unfinished"></translation>
+        <translation>Gruppeboks</translation>
     </message>
     <message>
-        <location filename="../../KvantumPreviewBase.ui" line="2315"/>
-        <location filename="../../KvantumPreviewBase.ui" line="2367"/>
-        <location filename="../../KvantumPreviewBase.ui" line="2661"/>
-        <location filename="../../KvantumPreviewBase.ui" line="2738"/>
-        <location filename="../../KvantumPreviewBase.ui" line="2786"/>
+        <location filename="../../KvantumPreviewBase.ui" line="2355"/>
+        <location filename="../../KvantumPreviewBase.ui" line="2407"/>
+        <location filename="../../KvantumPreviewBase.ui" line="2701"/>
+        <location filename="../../KvantumPreviewBase.ui" line="2778"/>
+        <location filename="../../KvantumPreviewBase.ui" line="2826"/>
         <source>Tab 1</source>
-        <translation type="unfinished"></translation>
+        <translation>Fane 1</translation>
     </message>
     <message>
-        <location filename="../../KvantumPreviewBase.ui" line="2321"/>
+        <location filename="../../KvantumPreviewBase.ui" line="2361"/>
         <source>Page 1 (disabled)</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../../KvantumPreviewBase.ui" line="2333"/>
-        <location filename="../../KvantumPreviewBase.ui" line="2381"/>
-        <location filename="../../KvantumPreviewBase.ui" line="2679"/>
-        <location filename="../../KvantumPreviewBase.ui" line="2752"/>
-        <location filename="../../KvantumPreviewBase.ui" line="2800"/>
-        <source>Tab 2</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../../KvantumPreviewBase.ui" line="2339"/>
-        <source>Page 2 (disabled)</source>
-        <translation type="unfinished"></translation>
+        <translation>Side 1 (avskrudd)</translation>
     </message>
     <message>
         <location filename="../../KvantumPreviewBase.ui" line="2373"/>
-        <location filename="../../KvantumPreviewBase.ui" line="2566"/>
-        <location filename="../../KvantumPreviewBase.ui" line="2621"/>
-        <location filename="../../KvantumPreviewBase.ui" line="2744"/>
+        <location filename="../../KvantumPreviewBase.ui" line="2421"/>
+        <location filename="../../KvantumPreviewBase.ui" line="2719"/>
         <location filename="../../KvantumPreviewBase.ui" line="2792"/>
+        <location filename="../../KvantumPreviewBase.ui" line="2840"/>
+        <source>Tab 2</source>
+        <translation>Fane 2</translation>
+    </message>
+    <message>
+        <location filename="../../KvantumPreviewBase.ui" line="2379"/>
+        <source>Page 2 (disabled)</source>
+        <translation>Side 2 (avskrudd)</translation>
+    </message>
+    <message>
+        <location filename="../../KvantumPreviewBase.ui" line="2413"/>
+        <location filename="../../KvantumPreviewBase.ui" line="2606"/>
+        <location filename="../../KvantumPreviewBase.ui" line="2661"/>
+        <location filename="../../KvantumPreviewBase.ui" line="2784"/>
+        <location filename="../../KvantumPreviewBase.ui" line="2832"/>
         <source>Page 1</source>
-        <translation type="unfinished"></translation>
+        <translation>Side 1</translation>
     </message>
     <message>
-        <location filename="../../KvantumPreviewBase.ui" line="2387"/>
-        <location filename="../../KvantumPreviewBase.ui" line="2594"/>
+        <location filename="../../KvantumPreviewBase.ui" line="2427"/>
         <location filename="../../KvantumPreviewBase.ui" line="2634"/>
-        <location filename="../../KvantumPreviewBase.ui" line="2685"/>
-        <location filename="../../KvantumPreviewBase.ui" line="2758"/>
-        <location filename="../../KvantumPreviewBase.ui" line="2806"/>
+        <location filename="../../KvantumPreviewBase.ui" line="2674"/>
+        <location filename="../../KvantumPreviewBase.ui" line="2725"/>
+        <location filename="../../KvantumPreviewBase.ui" line="2798"/>
+        <location filename="../../KvantumPreviewBase.ui" line="2846"/>
         <source>Page 2</source>
-        <translation type="unfinished"></translation>
+        <translation>Side 2</translation>
     </message>
     <message>
-        <location filename="../../KvantumPreviewBase.ui" line="2411"/>
+        <location filename="../../KvantumPreviewBase.ui" line="2451"/>
         <source>Stack widget (page1)</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../KvantumPreviewBase.ui" line="2425"/>
+        <location filename="../../KvantumPreviewBase.ui" line="2465"/>
         <source>Stack Widget (page2)</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../KvantumPreviewBase.ui" line="2442"/>
+        <location filename="../../KvantumPreviewBase.ui" line="2482"/>
         <source>Group box</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../KvantumPreviewBase.ui" line="2520"/>
+        <location filename="../../KvantumPreviewBase.ui" line="2560"/>
         <source>Dock Widget</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../KvantumPreviewBase.ui" line="2537"/>
+        <location filename="../../KvantumPreviewBase.ui" line="2577"/>
         <source>Checkable group box</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../KvantumPreviewBase.ui" line="2572"/>
+        <location filename="../../KvantumPreviewBase.ui" line="2612"/>
         <source>Tool Box</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../KvantumPreviewBase.ui" line="2667"/>
+        <location filename="../../KvantumPreviewBase.ui" line="2707"/>
         <source>Document mode</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../KvantumPreviewBase.ui" line="2705"/>
+        <location filename="../../KvantumPreviewBase.ui" line="2745"/>
         <source>Box frame</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../KvantumPreviewBase.ui" line="2835"/>
+        <location filename="../../KvantumPreviewBase.ui" line="2875"/>
         <source>&amp;File</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../KvantumPreviewBase.ui" line="2839"/>
+        <location filename="../../KvantumPreviewBase.ui" line="2879"/>
         <source>&amp;Submenu</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../KvantumPreviewBase.ui" line="2859"/>
+        <location filename="../../KvantumPreviewBase.ui" line="2899"/>
         <source>toolBar</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../KvantumPreviewBase.ui" line="2879"/>
+        <location filename="../../KvantumPreviewBase.ui" line="2919"/>
         <source>toolBar_2</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../KvantumPreviewBase.ui" line="2901"/>
+        <location filename="../../KvantumPreviewBase.ui" line="2941"/>
         <source>&amp;Quit</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../KvantumPreviewBase.ui" line="2904"/>
+        <location filename="../../KvantumPreviewBase.ui" line="2944"/>
         <source>Quit</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../KvantumPreviewBase.ui" line="2907"/>
+        <location filename="../../KvantumPreviewBase.ui" line="2947"/>
         <source>Ctrl+Q</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../KvantumPreviewBase.ui" line="2915"/>
+        <location filename="../../KvantumPreviewBase.ui" line="2955"/>
         <source>&amp;Checkbox</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../KvantumPreviewBase.ui" line="2928"/>
+        <location filename="../../KvantumPreviewBase.ui" line="2968"/>
         <source>Toggle Layout</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../KvantumPreviewBase.ui" line="2931"/>
+        <location filename="../../KvantumPreviewBase.ui" line="2971"/>
         <source>Toggle layout direction</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../KvantumPreviewBase.ui" line="2943"/>
+        <location filename="../../KvantumPreviewBase.ui" line="2983"/>
         <source>&amp;Doc Mode</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../KvantumPreviewBase.ui" line="2946"/>
+        <location filename="../../KvantumPreviewBase.ui" line="2986"/>
         <source>Show tabs in the document mode</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../KvantumPreviewBase.ui" line="2958"/>
+        <location filename="../../KvantumPreviewBase.ui" line="2998"/>
         <source>Menu Button</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../KvantumPreviewBase.ui" line="2961"/>
+        <location filename="../../KvantumPreviewBase.ui" line="3001"/>
         <source>Hold pressed to show a menu</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../KvantumPreviewBase.ui" line="2972"/>
+        <location filename="../../KvantumPreviewBase.ui" line="3012"/>
         <source>C&amp;heckbox</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../KvantumPreviewBase.ui" line="2980"/>
+        <location filename="../../KvantumPreviewBase.ui" line="3020"/>
         <source>&amp;Radio button</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../KvantumPreviewBase.ui" line="2988"/>
+        <location filename="../../KvantumPreviewBase.ui" line="3028"/>
         <source>Radio &amp;button</source>
         <translation type="unfinished"></translation>
     </message>
