@@ -6,7 +6,7 @@
     <message>
         <location filename="../../KvantumPreviewBase.ui" line="14"/>
         <source>Kvantum Preview</source>
-        <translation>Kvantum-voorbeeld</translation>
+        <translation>Kvantum-voorvertoning</translation>
     </message>
     <message>
         <location filename="../../KvantumPreviewBase.ui" line="29"/>
@@ -51,9 +51,8 @@ breedte</translation>
         <location filename="../../KvantumPreviewBase.ui" line="152"/>
         <source>Multi-line
  push button</source>
-        <translation>Drukknop
- met
-  meerdere regels</translation>
+        <translation>Drukknop met
+ meerdere regels</translation>
     </message>
     <message>
         <location filename="../../KvantumPreviewBase.ui" line="160"/>
@@ -97,8 +96,7 @@ drukknop</translation>
         <location filename="../../KvantumPreviewBase.ui" line="464"/>
         <source>Multi-line
 toolbutton</source>
-        <translation>Hulpmiddelknop
-met
+        <translation>Hulpmiddelknop met
 meerdere regels</translation>
     </message>
     <message>
@@ -114,7 +112,7 @@ met een pijl</translation>
         <location filename="../../KvantumPreviewBase.ui" line="584"/>
         <source>Toolbutton with 32px SVG icon
 and text below</source>
-        <translation>Hulpmiddelknop met 32px SVG-pictogram
+        <translation>Hulpmiddelknop met 32px svg-pictogram
 en tekst eronder</translation>
     </message>
     <message>
@@ -148,7 +146,7 @@ en pijl voor uitrollijst</translation>
         <location filename="../../KvantumPreviewBase.ui" line="539"/>
         <source>Toolbutton with 32px PNG icon
 beside text</source>
-        <translation>Hulpmiddelknop met 32px PNG-pictogram
+        <translation>Hulpmiddelknop met 32px png-pictogram
 naast tekst</translation>
     </message>
     <message>
@@ -193,42 +191,40 @@ breedte</translation>
         <location filename="../../KvantumPreviewBase.ui" line="867"/>
         <source>Multi-line
 radio button</source>
-        <translation>Keuzerondje
-met
+        <translation>Keuzerondje met
 meerdere regels</translation>
     </message>
     <message>
         <location filename="../../KvantumPreviewBase.ui" line="878"/>
         <location filename="../../KvantumPreviewBase.ui" line="904"/>
         <source>Radio button with 32px SVG icon</source>
-        <translation>Keuzerondje met 32px SVG-pictogram</translation>
+        <translation>Keuzerondje met 32px svg-pictogram</translation>
     </message>
     <message>
         <location filename="../../KvantumPreviewBase.ui" line="927"/>
         <location filename="../../KvantumPreviewBase.ui" line="940"/>
         <source>Simple check box</source>
-        <translation>Eenvoudig selectievakje</translation>
+        <translation>Eenvoudig aankruisvakje</translation>
     </message>
     <message>
         <location filename="../../KvantumPreviewBase.ui" line="950"/>
         <location filename="../../KvantumPreviewBase.ui" line="961"/>
         <source>Multi-line
 check box</source>
-        <translation>Selectievakje
-met
+        <translation>Aankruisvakje met
 meerdere regels</translation>
     </message>
     <message>
         <location filename="../../KvantumPreviewBase.ui" line="969"/>
         <location filename="../../KvantumPreviewBase.ui" line="982"/>
         <source>Tri-state check box</source>
-        <translation>Selectievakje met drie statussen</translation>
+        <translation>Aankruisvakje met drie statussen</translation>
     </message>
     <message>
         <location filename="../../KvantumPreviewBase.ui" line="992"/>
         <location filename="../../KvantumPreviewBase.ui" line="1006"/>
         <source>Check box with icon</source>
-        <translation>Selectievakje met pictogram</translation>
+        <translation>Aankruisvakje met pictogram</translation>
     </message>
     <message>
         <location filename="../../KvantumPreviewBase.ui" line="1062"/>
@@ -406,11 +402,13 @@ meerdere regels</translation>
     </message>
     <message>
         <location filename="../../KvantumPreviewBase.ui" line="2161"/>
+        <location filename="../../KvantumPreviewBase.ui" line="2259"/>
         <source>3rd Item</source>
         <translation>3e item</translation>
     </message>
     <message>
         <location filename="../../KvantumPreviewBase.ui" line="2169"/>
+        <location filename="../../KvantumPreviewBase.ui" line="2247"/>
         <source>2nd Item</source>
         <translation>2e item</translation>
     </message>
@@ -428,6 +426,7 @@ meerdere regels</translation>
     </message>
     <message>
         <location filename="../../KvantumPreviewBase.ui" line="2184"/>
+        <location filename="../../KvantumPreviewBase.ui" line="2232"/>
         <source>1st Item</source>
         <translation>1e item</translation>
     </message>
@@ -437,42 +436,42 @@ meerdere regels</translation>
         <translation>3e subitem</translation>
     </message>
     <message>
-        <location filename="../../KvantumPreviewBase.ui" line="2462"/>
+        <location filename="../../KvantumPreviewBase.ui" line="2502"/>
         <source>Row 0</source>
         <translation>Rij 0</translation>
     </message>
     <message>
-        <location filename="../../KvantumPreviewBase.ui" line="2467"/>
+        <location filename="../../KvantumPreviewBase.ui" line="2507"/>
         <source>Row 1</source>
         <translation>Rij 1</translation>
     </message>
     <message>
-        <location filename="../../KvantumPreviewBase.ui" line="2472"/>
+        <location filename="../../KvantumPreviewBase.ui" line="2512"/>
         <source>Column 0</source>
         <translation>Kolom 0</translation>
     </message>
     <message>
-        <location filename="../../KvantumPreviewBase.ui" line="2480"/>
+        <location filename="../../KvantumPreviewBase.ui" line="2520"/>
         <source>Column 1</source>
         <translation>Kolom 1</translation>
     </message>
     <message>
-        <location filename="../../KvantumPreviewBase.ui" line="2485"/>
+        <location filename="../../KvantumPreviewBase.ui" line="2525"/>
         <source>0-0</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../../KvantumPreviewBase.ui" line="2493"/>
+        <location filename="../../KvantumPreviewBase.ui" line="2533"/>
         <source>0-1</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../../KvantumPreviewBase.ui" line="2501"/>
+        <location filename="../../KvantumPreviewBase.ui" line="2541"/>
         <source>1-0</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../../KvantumPreviewBase.ui" line="2509"/>
+        <location filename="../../KvantumPreviewBase.ui" line="2549"/>
         <source>1-1</source>
         <translation></translation>
     </message>
@@ -488,191 +487,191 @@ meerdere regels</translation>
         <translation>Niet-bewerkbaar</translation>
     </message>
     <message>
-        <location filename="../../KvantumPreviewBase.ui" line="2229"/>
+        <location filename="../../KvantumPreviewBase.ui" line="2269"/>
         <source>Subwindow</source>
         <translation>Subvenster</translation>
     </message>
     <message>
-        <location filename="../../KvantumPreviewBase.ui" line="2276"/>
+        <location filename="../../KvantumPreviewBase.ui" line="2316"/>
         <source>Panel frame</source>
         <translation>Paneelrand</translation>
     </message>
     <message>
-        <location filename="../../KvantumPreviewBase.ui" line="2295"/>
-        <location filename="../../KvantumPreviewBase.ui" line="2436"/>
-        <location filename="../../KvantumPreviewBase.ui" line="2528"/>
+        <location filename="../../KvantumPreviewBase.ui" line="2335"/>
+        <location filename="../../KvantumPreviewBase.ui" line="2476"/>
+        <location filename="../../KvantumPreviewBase.ui" line="2568"/>
         <source>GroupBox</source>
         <translation>Frame</translation>
     </message>
     <message>
-        <location filename="../../KvantumPreviewBase.ui" line="2315"/>
-        <location filename="../../KvantumPreviewBase.ui" line="2367"/>
-        <location filename="../../KvantumPreviewBase.ui" line="2661"/>
-        <location filename="../../KvantumPreviewBase.ui" line="2738"/>
-        <location filename="../../KvantumPreviewBase.ui" line="2786"/>
+        <location filename="../../KvantumPreviewBase.ui" line="2355"/>
+        <location filename="../../KvantumPreviewBase.ui" line="2407"/>
+        <location filename="../../KvantumPreviewBase.ui" line="2701"/>
+        <location filename="../../KvantumPreviewBase.ui" line="2778"/>
+        <location filename="../../KvantumPreviewBase.ui" line="2826"/>
         <source>Tab 1</source>
         <translation>Tabblad 1</translation>
     </message>
     <message>
-        <location filename="../../KvantumPreviewBase.ui" line="2321"/>
+        <location filename="../../KvantumPreviewBase.ui" line="2361"/>
         <source>Page 1 (disabled)</source>
         <translation>Pagina 1 (uitgeschakeld)</translation>
     </message>
     <message>
-        <location filename="../../KvantumPreviewBase.ui" line="2333"/>
-        <location filename="../../KvantumPreviewBase.ui" line="2381"/>
-        <location filename="../../KvantumPreviewBase.ui" line="2679"/>
-        <location filename="../../KvantumPreviewBase.ui" line="2752"/>
-        <location filename="../../KvantumPreviewBase.ui" line="2800"/>
+        <location filename="../../KvantumPreviewBase.ui" line="2373"/>
+        <location filename="../../KvantumPreviewBase.ui" line="2421"/>
+        <location filename="../../KvantumPreviewBase.ui" line="2719"/>
+        <location filename="../../KvantumPreviewBase.ui" line="2792"/>
+        <location filename="../../KvantumPreviewBase.ui" line="2840"/>
         <source>Tab 2</source>
         <translation>Tabblad 2</translation>
     </message>
     <message>
-        <location filename="../../KvantumPreviewBase.ui" line="2339"/>
+        <location filename="../../KvantumPreviewBase.ui" line="2379"/>
         <source>Page 2 (disabled)</source>
         <translation>Pagina 2 (uitgeschakeld)</translation>
     </message>
     <message>
-        <location filename="../../KvantumPreviewBase.ui" line="2373"/>
-        <location filename="../../KvantumPreviewBase.ui" line="2566"/>
-        <location filename="../../KvantumPreviewBase.ui" line="2621"/>
-        <location filename="../../KvantumPreviewBase.ui" line="2744"/>
-        <location filename="../../KvantumPreviewBase.ui" line="2792"/>
+        <location filename="../../KvantumPreviewBase.ui" line="2413"/>
+        <location filename="../../KvantumPreviewBase.ui" line="2606"/>
+        <location filename="../../KvantumPreviewBase.ui" line="2661"/>
+        <location filename="../../KvantumPreviewBase.ui" line="2784"/>
+        <location filename="../../KvantumPreviewBase.ui" line="2832"/>
         <source>Page 1</source>
         <translation>Pagina 1</translation>
     </message>
     <message>
-        <location filename="../../KvantumPreviewBase.ui" line="2387"/>
-        <location filename="../../KvantumPreviewBase.ui" line="2594"/>
+        <location filename="../../KvantumPreviewBase.ui" line="2427"/>
         <location filename="../../KvantumPreviewBase.ui" line="2634"/>
-        <location filename="../../KvantumPreviewBase.ui" line="2685"/>
-        <location filename="../../KvantumPreviewBase.ui" line="2758"/>
-        <location filename="../../KvantumPreviewBase.ui" line="2806"/>
+        <location filename="../../KvantumPreviewBase.ui" line="2674"/>
+        <location filename="../../KvantumPreviewBase.ui" line="2725"/>
+        <location filename="../../KvantumPreviewBase.ui" line="2798"/>
+        <location filename="../../KvantumPreviewBase.ui" line="2846"/>
         <source>Page 2</source>
         <translation>Pagina 2</translation>
     </message>
     <message>
-        <location filename="../../KvantumPreviewBase.ui" line="2411"/>
+        <location filename="../../KvantumPreviewBase.ui" line="2451"/>
         <source>Stack widget (page1)</source>
         <translation>Stapelelement (pagina1)</translation>
     </message>
     <message>
-        <location filename="../../KvantumPreviewBase.ui" line="2425"/>
+        <location filename="../../KvantumPreviewBase.ui" line="2465"/>
         <source>Stack Widget (page2)</source>
         <translation>Stapelelement (pagina2)</translation>
     </message>
     <message>
-        <location filename="../../KvantumPreviewBase.ui" line="2442"/>
+        <location filename="../../KvantumPreviewBase.ui" line="2482"/>
         <source>Group box</source>
         <translation>Frame</translation>
     </message>
     <message>
-        <location filename="../../KvantumPreviewBase.ui" line="2520"/>
+        <location filename="../../KvantumPreviewBase.ui" line="2560"/>
         <source>Dock Widget</source>
         <translation>Dockelement</translation>
     </message>
     <message>
-        <location filename="../../KvantumPreviewBase.ui" line="2537"/>
+        <location filename="../../KvantumPreviewBase.ui" line="2577"/>
         <source>Checkable group box</source>
-        <translation>Aanvinkbaar frame</translation>
+        <translation>Aankruisbaar frame</translation>
     </message>
     <message>
-        <location filename="../../KvantumPreviewBase.ui" line="2572"/>
+        <location filename="../../KvantumPreviewBase.ui" line="2612"/>
         <source>Tool Box</source>
         <translation>Werkbalk</translation>
     </message>
     <message>
-        <location filename="../../KvantumPreviewBase.ui" line="2667"/>
+        <location filename="../../KvantumPreviewBase.ui" line="2707"/>
         <source>Document mode</source>
         <translation>Documentmodus</translation>
     </message>
     <message>
-        <location filename="../../KvantumPreviewBase.ui" line="2705"/>
+        <location filename="../../KvantumPreviewBase.ui" line="2745"/>
         <source>Box frame</source>
         <translation>Balkframe</translation>
     </message>
     <message>
-        <location filename="../../KvantumPreviewBase.ui" line="2835"/>
+        <location filename="../../KvantumPreviewBase.ui" line="2875"/>
         <source>&amp;File</source>
         <translation>&amp;Bestand</translation>
     </message>
     <message>
-        <location filename="../../KvantumPreviewBase.ui" line="2839"/>
+        <location filename="../../KvantumPreviewBase.ui" line="2879"/>
         <source>&amp;Submenu</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../../KvantumPreviewBase.ui" line="2859"/>
+        <location filename="../../KvantumPreviewBase.ui" line="2899"/>
         <source>toolBar</source>
         <translation>werkBalk</translation>
     </message>
     <message>
-        <location filename="../../KvantumPreviewBase.ui" line="2879"/>
+        <location filename="../../KvantumPreviewBase.ui" line="2919"/>
         <source>toolBar_2</source>
         <translation>werkBalk_2</translation>
     </message>
     <message>
-        <location filename="../../KvantumPreviewBase.ui" line="2901"/>
+        <location filename="../../KvantumPreviewBase.ui" line="2941"/>
         <source>&amp;Quit</source>
         <translation>&amp;Afsluiten</translation>
     </message>
     <message>
-        <location filename="../../KvantumPreviewBase.ui" line="2904"/>
+        <location filename="../../KvantumPreviewBase.ui" line="2944"/>
         <source>Quit</source>
         <translation>Afsluiten</translation>
     </message>
     <message>
-        <location filename="../../KvantumPreviewBase.ui" line="2907"/>
+        <location filename="../../KvantumPreviewBase.ui" line="2947"/>
         <source>Ctrl+Q</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../../KvantumPreviewBase.ui" line="2915"/>
+        <location filename="../../KvantumPreviewBase.ui" line="2955"/>
         <source>&amp;Checkbox</source>
-        <translation>Sele&amp;ctievakje</translation>
+        <translation>Aan&amp;kruisvakje</translation>
     </message>
     <message>
-        <location filename="../../KvantumPreviewBase.ui" line="2928"/>
+        <location filename="../../KvantumPreviewBase.ui" line="2968"/>
         <source>Toggle Layout</source>
         <translation>Schakelen tussen indelingen</translation>
     </message>
     <message>
-        <location filename="../../KvantumPreviewBase.ui" line="2931"/>
+        <location filename="../../KvantumPreviewBase.ui" line="2971"/>
         <source>Toggle layout direction</source>
         <translation>Schakelen tussen indelingsrichtingen</translation>
     </message>
     <message>
-        <location filename="../../KvantumPreviewBase.ui" line="2943"/>
+        <location filename="../../KvantumPreviewBase.ui" line="2983"/>
         <source>&amp;Doc Mode</source>
         <translation>&amp;Documentmodus</translation>
     </message>
     <message>
-        <location filename="../../KvantumPreviewBase.ui" line="2946"/>
+        <location filename="../../KvantumPreviewBase.ui" line="2986"/>
         <source>Show tabs in the document mode</source>
         <translation>Tabbladen tonen in documentmodus</translation>
     </message>
     <message>
-        <location filename="../../KvantumPreviewBase.ui" line="2958"/>
+        <location filename="../../KvantumPreviewBase.ui" line="2998"/>
         <source>Menu Button</source>
         <translation>Menuknop</translation>
     </message>
     <message>
-        <location filename="../../KvantumPreviewBase.ui" line="2961"/>
+        <location filename="../../KvantumPreviewBase.ui" line="3001"/>
         <source>Hold pressed to show a menu</source>
         <translation>Houdt ingedrukt om een menu te tonen</translation>
     </message>
     <message>
-        <location filename="../../KvantumPreviewBase.ui" line="2972"/>
+        <location filename="../../KvantumPreviewBase.ui" line="3012"/>
         <source>C&amp;heckbox</source>
-        <translation>Sele&amp;ctievakje</translation>
+        <translation>Aan&amp;kruisvakje</translation>
     </message>
     <message>
-        <location filename="../../KvantumPreviewBase.ui" line="2980"/>
+        <location filename="../../KvantumPreviewBase.ui" line="3020"/>
         <source>&amp;Radio button</source>
         <translation>Keuze&amp;rondje</translation>
     </message>
     <message>
-        <location filename="../../KvantumPreviewBase.ui" line="2988"/>
+        <location filename="../../KvantumPreviewBase.ui" line="3028"/>
         <source>Radio &amp;button</source>
         <translation>Keuze&amp;rondje</translation>
     </message>
