@@ -106,14 +106,7 @@ class BlurHelper: public QObject
     QList<qreal> menuShadow_;
     QList<qreal> tooltipShadow_;
 
-#if (QT_VERSION < QT_VERSION_CHECK(5,11,0))
-#if defined Q_WS_X11 || defined Q_OS_LINUX
-    /* The required atom. */
-    Atom atom_blur_;
-#endif
-#else
     qreal contrast_, intensity_, saturation_;
-#endif
 };
 }
 
