@@ -15,14 +15,6 @@
  * with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-/*
-  NOTE:
-  This is for Qt >= 5.15, which can call the WM drag with QWindow::startSystemMove().
-  It shouldn't have the style as its parent because the style may be deleted after it
-  sends a mouse event (and in response to that event) but before its methods return.
-  It can be safely deleted by QObject::deleteLater() in the style's destructor.
-*/
-
 #include <QMouseEvent>
 #include <QApplication>
 #include <QMainWindow>
@@ -31,6 +23,7 @@
 #include <QMenuBar>
 #include <QToolBar>
 #include <QStatusBar>
+#include <QToolButton>
 #include <QCheckBox>
 #include <QRadioButton>
 #include <QGroupBox>
@@ -45,6 +38,8 @@
 
 namespace Kvantum {
 
+static bool _WMExists = false;
+
 static inline bool isPrimaryToolBar (QWidget *w)
 {
   if (w == nullptr) return false;
@@ -87,10 +82,10 @@ static inline QWidget* toolbarContainer (QWidget *w)
 }
 
 WindowManager::WindowManager (QObject *parent, Drag drag, bool dragFromBtns) :
-               QObject (parent), // nullptr
+               QObject (parent),
                enabled_ (true),
                dragDistance_ (qMax (QApplication::startDragDistance(), 10)),
-               dragDelay_ (qMax (QApplication::startDragTime(), 50)),
+               dragDelay_ (qMax (QApplication::startDragTime(), 500)),
                doubleClickInterval_ (QApplication::doubleClickInterval()),
                isDelayed_ (false),
                dragAboutToStart_ (false),
@@ -103,6 +98,11 @@ WindowManager::WindowManager (QObject *parent, Drag drag, bool dragFromBtns) :
   qApp->installEventFilter (_appEventFilter);
 }
 /*************************/
+WindowManager::~WindowManager()
+{
+  _WMExists = false;
+}
+/*************************/
 void WindowManager::initialize (const QStringList &blackList)
 {
   setEnabled (true);
@@ -147,6 +147,7 @@ void WindowManager::initializeBlackList (const QStringList &list)
   blackList_.insert (ExceptionId (QStringLiteral ("CustomTrackView@kdenlive")));
   blackList_.insert (ExceptionId (QStringLiteral ("MuseScore")));
   blackList_.insert (ExceptionId (QStringLiteral ("KGameCanvasWidget")));
+  blackList_.insert (ExceptionId (QStringLiteral ("QQuickWidget")));
   for (const QString& exception : list)
   {
     ExceptionId id (exception);
@@ -216,30 +217,45 @@ void WindowManager::timerEvent (QTimerEvent *event)
     {
       if (qApp->activePopupWidget())
       {
-        /* Due to a Qt bug, that exists under X11 and Wayland alike,
-           the drag may be started even when an active popup is shown.
-           As a workaround, we don't start dragging in this case. */
+        /* WARNING: Due to a Qt bug, that exists under X11 and Wayland alike,
+                    the drag may be started even when an active popup is shown.
+                    As a workaround, we don't start dragging in this case. */
         winTarget_.data()->unsetCursor();
         resetDrag();
         unlock();
+        isDelayed_ = false;
       }
-      /* NOTE: Under X11, if dragging is started with a delay and the left
-               mouse button is released shortly after it, it will continue
-               until a mouse button is pressed or the mouse wheel is turned.
-               As a workaround, we don't start dragging with a delay but
-               only change and restore the window cursor appropriately. */
       else if (isDelayed_)
+      {
+        /* NOTE: Under X11, if dragging is started with a delay and the left
+                 mouse button is released shortly after it, it will continue
+                 until a mouse button is pressed or the mouse wheel is turned.
+                 As a workaround, we don't start dragging with a delay but
+                 only change and restore the window cursor appropriately. */
         winTarget_.data()->setCursor (Qt::OpenHandCursor);
+        isDelayed_ = false;
+      }
       else
       {
-        if (widgetTarget_) // release mouse outside the widget on dragging
-          widgetMouseRelease();
         winTarget_.data()->unsetCursor();
-        dragInProgress_ = winTarget_.data()->startSystemMove();
+        _WMExists = true;
+        if (widgetTarget_)
+        {
+          /* NOTE: On starting the drag, we release the mouse outside the widget to
+                   prevent a click and also counterbalance the mouse press that was
+                   sent by WindowManager::mousePressEvent(). In this way, it's also
+                   possible to drag from button-like widgets safely (as in GTK). */
+          QMouseEvent e (QEvent::MouseButtonRelease,
+                         QPoint (-1, -1),
+                         Qt::LeftButton, Qt::LeftButton, Qt::NoModifier);
+          qApp->sendEvent (widgetTarget_.data(), &e);
+        }
+        if (!_WMExists) return; // see mousePressEvent for the reason
+        if (winTarget_)
+          dragInProgress_ = winTarget_.data()->startSystemMove();
         resetDrag(); // clear the drag info, showing that the drag is started
       }
     }
-    isDelayed_ = false;
   }
   else if (event->timerId() == doubleClickTimer_.timerId())
     doubleClickTimer_.stop();
@@ -311,6 +327,8 @@ bool WindowManager::mousePressEvent (QObject *object, QEvent *event)
   widgetDragPoint_ = widget->mapFromGlobal (mouseEvent->globalPos()); // needed by canDrag()
 
   /* check if the widget can be dragged */
+  dragDistance_ = qMax (QApplication::startDragDistance(), 10);
+  dragDelay_ = qMax (QApplication::startDragTime(), 500);
   if (isBlackListed (widget) || !canDrag (widget))
     return false;
 
@@ -324,19 +342,25 @@ bool WindowManager::mousePressEvent (QObject *object, QEvent *event)
   pressedWidget_.clear();
   lastPressedWidget_.clear();
 
-  /* Because the widget may react to mouse press events, we first send a press event to it.
-     A release event will be sent in WindowManager::AppEventFilter::eventFilter. */
+  _WMExists = true;
+
+  /* Because the widget may react to mouse press events,
+     we first send a press event to it. */
   QMouseEvent mousePress (QEvent::MouseButtonPress, widgetDragPoint_, Qt::LeftButton, Qt::LeftButton, Qt::NoModifier);
   qApp->sendEvent (widget, &mousePress);
 
+  /* Theoretically, it's possible that the WindowManager instance
+     gets deleted as the result of the above mouse press event. */
+  if (!_WMExists)
+    return true;
+
   /* If the target window is left, blocked or hidden now, the drag
      is cancelled (-> leavingWindow). Steal the press event! */
   if (winTarget_ == nullptr)
     return true;
 
   if (widgetTarget_ == nullptr // the widget has been deleted
-      || !widget->isVisible() // as with Fm::PathBar
-      || !widget->isEnabled())
+      || !widget->isVisible()) // as with Fm::PathBar
   {
     resetDrag();
     return true;
@@ -375,6 +399,10 @@ bool WindowManager::mousePressEvent (QObject *object, QEvent *event)
 /*************************/
 bool WindowManager::mouseMoveEvent (QEvent *event)
 {
+  /* make sure that the left mouse button is still pressed */
+  if (!(static_cast<QMouseEvent*>(event)->buttons() & Qt::LeftButton))
+    return false;
+
   if (!dragInProgress_)
   {
     QMouseEvent *mouseEvent = static_cast<QMouseEvent*>(event);
@@ -383,7 +411,7 @@ bool WindowManager::mouseMoveEvent (QEvent *event)
       dragAboutToStart_ = false;
       if (dragTimer_.isActive())
         dragTimer_.stop();
-      if (mouseEvent->globalPos() == globalDragPoint_)
+      if (QPoint (mouseEvent->globalPos() - globalDragPoint_).manhattanLength() < dragDistance_)
       {
         isDelayed_ = true;
         dragTimer_.start (dragDelay_, this);
@@ -419,7 +447,10 @@ bool WindowManager::mouseReleaseEvent (QEvent *event)
     QMouseEvent *mouseEvent = static_cast<QMouseEvent*>(event);
     if (mouseEvent->button() == Qt::LeftButton)
     {
-      widgetMouseRelease (true);
+      auto e = new QMouseEvent (QEvent::MouseButtonRelease,
+                                widgetDragPoint_,
+                                Qt::LeftButton, Qt::LeftButton, Qt::NoModifier);
+      qApp->postEvent (widgetTarget_.data(), e);
       resetDrag();
       unlock();
     }
@@ -466,7 +497,7 @@ bool WindowManager::isBlackListed (QWidget *widget)
 /*************************/
 bool WindowManager::canDrag (QWidget *widget)
 {
-  if (!widget || !widget->isEnabled() || !enabled()
+  if (!widget || !enabled()
       || drag_ == DRAG_NONE) // impossible
   {
     return false;
@@ -511,6 +542,9 @@ bool WindowManager::canDrag (QWidget *widget)
     parent = parent->parentWidget();
   }
 
+  if (qobject_cast<QMdiArea*>(widget->parentWidget()))
+    return false;
+
   if (QMenuBar *menuBar = qobject_cast<QMenuBar*>(widget))
   {
     if (menuBar->activeAction() && menuBar->activeAction()->isEnabled())
@@ -536,8 +570,11 @@ bool WindowManager::canDrag (QWidget *widget)
     if (tb == nullptr) return false;
 
     /* consider some widgets inside toolbars */
-    if (((!dragFromBtns_ || !qobject_cast<QAbstractButton*>(widget))
-         && widget->testAttribute (Qt::WA_Hover))
+    bool draggedBtn (dragFromBtns_ && qobject_cast<QAbstractButton*>(widget));
+    bool allowedBtn = false;
+    if (QToolButton *toolButton = qobject_cast<QToolButton*>(widget))
+      allowedBtn = toolButton->autoRaise() && !toolButton->isEnabled();
+    if ((!draggedBtn && !allowedBtn && widget->testAttribute (Qt::WA_Hover))
         || widget->testAttribute (Qt::WA_SetCursor))
     {
       return false;
@@ -548,7 +585,13 @@ bool WindowManager::canDrag (QWidget *widget)
         return false;
     }
 
-    return isPrimaryToolBar (tb);
+    if (!isPrimaryToolBar (tb)) return false;
+    if (draggedBtn)
+    { // to make pressing buttons easier
+      dragDistance_ *= 1.5;
+      dragDelay_ *= 2;
+    }
+    return true;
   }
 
   if (QTabBar *tabBar = qobject_cast<QTabBar*>(widget))
@@ -679,8 +722,11 @@ bool WindowManager::canDrag (QWidget *widget)
   else if (qobject_cast<QDockWidget*>(widget->parentWidget()))
     return !qobject_cast<QAbstractButton*>(widget); // not a titlebar button
 
-  if (((!dragFromBtns_ || !qobject_cast<QAbstractButton*>(widget))
-       && widget->testAttribute (Qt::WA_Hover))
+  bool draggedBtn (dragFromBtns_ && qobject_cast<QAbstractButton*>(widget));
+  bool allowedBtn = false;
+  if (QToolButton *toolButton = qobject_cast<QToolButton*>(widget))
+    allowedBtn = toolButton->autoRaise() && !toolButton->isEnabled();
+  if ((!draggedBtn && !allowedBtn && widget->testAttribute (Qt::WA_Hover))
       || widget->testAttribute (Qt::WA_SetCursor))
   {
     return false;
@@ -693,15 +739,17 @@ bool WindowManager::canDrag (QWidget *widget)
       return false;
   }
 
-  if (qobject_cast<QMdiArea*>(widget->parentWidget()))
-    return false;
-
   if (widget->focusPolicy() > Qt::TabFocus
       || (widget->focusProxy() && widget->focusProxy()->focusPolicy() > Qt::TabFocus))
   { // like an ordinary mouse press
     widget->setFocus (Qt::MouseFocusReason);
   }
 
+  if (draggedBtn)
+  { // to make pressing buttons easier
+    dragDistance_ *= 1.5;
+    dragDelay_ *= 2;
+  }
   return true;
 }
 /*************************/
@@ -710,8 +758,16 @@ bool WindowManager::isDraggable (QWidget *widget)
   if (!widget || QWidget::mouseGrabber())
     return false;
 
-  if (dragFromBtns_ && qobject_cast<QAbstractButton*>(widget))
-    return true;
+  if (qobject_cast<QAbstractButton*>(widget))
+  {
+    if (dragFromBtns_)
+      return true;
+    if (QToolButton *toolButton = qobject_cast<QToolButton*>(widget))
+    {
+      if (toolButton->autoRaise() && !toolButton->isEnabled())
+        return true;
+    }
+  }
 
   if (widget->isWindow()
       && (qobject_cast<QMainWindow*>(widget)
@@ -761,22 +817,6 @@ void WindowManager::resetDrag()
   dragAboutToStart_ = false;
 }
 /*************************/
-void WindowManager::widgetMouseRelease (bool inside)
-{
-  /*
-     Send a mouse release event to the widget, in order to counterbalance
-     the mouse press that was sent by WindowManager::mousePressEvent().
-
-     On starting the drag, we release the mouse outside the widget to
-     prevent a click. In this way, it's possible to drag from button-like
-     widgets safely (as in GTK).
-  */
-  QMouseEvent mouseRelease (QEvent::MouseButtonRelease,
-                            inside ? widgetDragPoint_ : QPoint (-1, -1),
-                            Qt::LeftButton, Qt::LeftButton, Qt::NoModifier);
-  qApp->sendEvent (widgetTarget_.data(), &mouseRelease);
-}
-/*************************/
 bool WindowManager::AppEventFilter::eventFilter (QObject *object, QEvent *event)
 {
   if (event->type() == QEvent::MouseButtonPress && !parent_->isLocked())
