@@ -185,7 +185,7 @@ void Style::drawBg(QPainter *p, const QWidget *widget) const
   int dw = sspec.incrementW ? sspec.minW : qMax(sspec.minW - bgndRect.width(), 0);
   if (!renderInterior(p,bgndRect.adjusted(0,0,dw,dh),fspec,ispec,ispec.element+suffix))
   { // no window interior element but with reduced translucency
-    p->fillRect(bgndRect, standardPalette().color(suffix.contains("-inactive")
+    p->fillRect(bgndRect, standardPalette().color(suffix.contains(QLatin1String("-inactive"))
                                                     ? QPalette::Inactive
                                                     : QPalette::Active,
                                                   QPalette::Window));
@@ -300,9 +300,23 @@ bool Style::eventFilter(QObject *o, QEvent *e)
         /* find the state and set the text color accordingly */
         int state;
         QPalette pPalette = option.palette;
-        QColor col;
+        QColor col, disabledCol;
         if (!cbtn->isEnabled())
+        {
           state = 0;
+          if (cbtn->isChecked())
+          {
+            if (isInactive)
+              disabledCol = getFromRGBA(lspec.toggleInactiveColor);
+            if (!disabledCol.isValid())
+              disabledCol = getFromRGBA(lspec.toggleColor);
+            if (disabledCol.isValid())
+            {
+              disabledCol.setAlpha(102); // 0.4 * disabledCol.alpha()
+              pPalette.setColor(QPalette::Disabled, QPalette::ButtonText, disabledCol);
+            }
+          }
+        }
         else if (cbtn->isChecked())
         {
           state = 4;
@@ -345,7 +359,11 @@ bool Style::eventFilter(QObject *o, QEvent *e)
         if (!cbtn->icon().isNull())
           p.drawPixmap(leftMargin + hOffset, topMargin + vOffset,
                        getPixmapFromIcon(cbtn->icon(),
-                                         getIconMode(state, isInactive, lspec),
+                                         getIconMode(disabledCol.isValid()
+                                                     && !enoughContrast(disabledCol,
+                                                                        standardPalette().color(QPalette::Window))
+                                                       ? -1 : state,
+                                                     isInactive, lspec),
                                          cbtn->isChecked() ? QIcon::On : QIcon::Off,
                                          cbtn->iconSize()));
 
@@ -504,7 +522,7 @@ bool Style::eventFilter(QObject *o, QEvent *e)
         if (!w->hasFocus())
           animationStartState_ = "normal";
         /* the popup may have been closed (with Qt5) */
-        else if (!(animatedWidget_ == w && animationStartState_.startsWith("c-toggled")))
+        else if (!(animatedWidget_ == w && animationStartState_.startsWith(QLatin1String("c-toggled"))))
           animationStartState_ = "pressed";
         if (isWidgetInactive(w))
           animationStartState_.append("-inactive");
@@ -538,8 +556,8 @@ bool Style::eventFilter(QObject *o, QEvent *e)
           animatedWidget_->update();
         }
         if (!(animatedWidget_ == w
-              && (animationStartState_.startsWith("c-toggled")
-                  || animationStartState_.startsWith("normal"))))
+              && (animationStartState_.startsWith(QLatin1String("c-toggled"))
+                  || animationStartState_.startsWith(QLatin1String("normal")))))
         { // it was hidden or another widget was interacted with  -- there's no other possibility
           animationStartState_ = "normal";
           if (isWidgetInactive(w))
@@ -904,17 +922,11 @@ bool Style::eventFilter(QObject *o, QEvent *e)
             progressTimer_->start(50);
         }
       }
-#if (QT_VERSION >= QT_VERSION_CHECK(5,11,0))
       else if (QMenu *menu = qobject_cast<QMenu*>(o))
-#else
-      else if (qobject_cast<QMenu*>(o))
-#endif
       {
         //if (isLibreoffice_) break;
         if (w->testAttribute(Qt::WA_X11NetWmWindowTypeMenu)) break; // detached menu
-#if (QT_VERSION >= QT_VERSION_CHECK(5,12,0))
         if (w->testAttribute(Qt::WA_StyleSheetTarget)) break; // not drawn by Kvantum (see PM_MenuHMargin)
-#endif
         if (movedMenus.contains(w)) break; // already moved
         /* "magical" condition for a submenu */
         QPoint parentMenuCorner;
@@ -1133,7 +1145,6 @@ bool Style::eventFilter(QObject *o, QEvent *e)
             dY -= static_cast<qreal>(getFrameSpec(group).bottom);
         }
 
-#if (QT_VERSION >= QT_VERSION_CHECK(5,11,0))
         /* compensate for an annoyance in Qt 5.11 -> QMenu::internalDelayedPopup() */
         if (parentMenu)
         {
@@ -1153,7 +1164,6 @@ bool Style::eventFilter(QObject *o, QEvent *e)
             }
           }
         }
-#endif
 
         int DX = qRound(dX);
         int DY = qRound(dY);
@@ -1292,26 +1302,22 @@ bool Style::eventFilter(QObject *o, QEvent *e)
           opacifyColor(col1);
         }
         palette.setColor(QPalette::Inactive, QPalette::Text, col1);
-#if (QT_VERSION >= QT_VERSION_CHECK(5,12,0))
         col1 = col; // placeholder
         col1.setAlpha(128);
         opacifyColor(col1);
         palette.setColor(QPalette::PlaceholderText, col1);
-#endif
         col.setAlpha(102); // 0.4 * disabledCol.alpha()
         opacifyColor(col);
         palette.setColor(QPalette::Disabled, QPalette::Text,col);
         forcePalette(w, palette);
-#if (QT_VERSION >= QT_VERSION_CHECK(5,12,0))
         /* also correct the color of the symbolic clear icon (-> CE_ToolBar) */
         if (QAction *clearAction = w->findChild<QAction*>(QLatin1String("_q_qlineeditclearaction")))
           clearAction->setIcon(standardIcon(QStyle::SP_LineEditClearButton, nullptr, w));
-#endif
       }
     }
     break;
 
-  case QEvent::PaletteChange :
+  /*case QEvent::PaletteChange :
     if (!isPcmanfm_ && qobject_cast<QLineEdit*>(o) && (tspec_.combo_as_lineedit || tspec_.square_combo_button))
     {
       if (QComboBox *cb = qobject_cast<QComboBox*>(w->parentWidget()))
@@ -1320,7 +1326,7 @@ bool Style::eventFilter(QObject *o, QEvent *e)
           cb->update(); // a workaround for bad codes that change line-edit base color
       }
     }
-    break;
+    break;*/
 
   case QEvent::Hide:
     if (qobject_cast<QToolButton*>(o))
