@@ -1,5 +1,5 @@
 /*
- * Copyright (C) Pedram Pourang (aka Tsu Jan) 2014-2019 <tsujan2000@gmail.com>
+ * Copyright (C) Pedram Pourang (aka Tsu Jan) 2014-2021 <tsujan2000@gmail.com>
  *
  * Kvantum is free software: you can redistribute it and/or modify it
  * under the terms of the GNU General Public License as published by the
@@ -40,7 +40,7 @@
 #include <QWindow>
 #include <QDialog>
 #include <QLayout> // only for forceSizeGrip
-#include <QCompleter> // only for combo menu change in  Kvantum Manager
+#include <QCompleter> // only for combo menu change in Kvantum Manager
 #include <QScroller>
 
 namespace Kvantum
@@ -52,31 +52,33 @@ static QString readDconfSetting(const QString &setting) // by Craig Drummond
   // Destroying the QProcess seems to block, causing the app to appear to hang before starting.
   // So, create QProcess on the heap - and only wait 1.5s for response. Connect finished to deleteLater
   // so that the object is destroyed.
-  QString schemeToUse=QLatin1String("/org/gnome/desktop/interface/");
-  QProcess *process=new QProcess();
-  process->start(QLatin1String("dconf"), QStringList() << QLatin1String("read") << schemeToUse+setting);
+  QString schemeToUse = QLatin1String("/org/gnome/desktop/interface/");
+  QProcess *process = new QProcess();
+  process->start(QLatin1String("dconf"), QStringList() << QLatin1String("read") << schemeToUse + setting);
   QObject::connect(process, static_cast<void(QProcess::*)(int, QProcess::ExitStatus)>(&QProcess::finished),
                    [=](int /*exitCode*/, QProcess::ExitStatus /*exitStatus*/){ process->deleteLater(); });
 
-  if (process->waitForFinished(1500)) {
+  if (process->waitForFinished(1500))
+  {
     QString resp = process->readAllStandardOutput();
     resp = resp.trimmed();
     resp.remove('\'');
 
-    if (resp.isEmpty()) {
-      // Probably set to the default, and dconf does not store defaults! Therefore, need to read via gsettings...
+    if (resp.isEmpty())
+    { // Probably set to the default, and dconf does not store defaults! Therefore, need to read via gsettings...
       schemeToUse=schemeToUse.mid(1, schemeToUse.length()-2).replace("/", ".");
-      QProcess *gsettingsProc=new QProcess();
+      QProcess *gsettingsProc = new QProcess();
       gsettingsProc->start(QLatin1String("gsettings"), QStringList() << QLatin1String("get") << schemeToUse << setting);
       QObject::connect(gsettingsProc, static_cast<void(QProcess::*)(int, QProcess::ExitStatus)>(&QProcess::finished),
                        [=](int /*exitCode*/, QProcess::ExitStatus /*exitStatus*/){ process->deleteLater(); });
-      if (gsettingsProc->waitForFinished(1500)) {
+      if (gsettingsProc->waitForFinished(1500))
+      {
         resp = gsettingsProc->readAllStandardOutput();
         resp = resp.trimmed();
         resp.remove('\'');
-      } else {
-        gsettingsProc->kill();
       }
+      else
+        gsettingsProc->kill();
     }
     return resp;
   }
@@ -104,7 +106,7 @@ static void setAppFont()
     if (parts.length()>1)
     {
       uint size = parts.takeLast().toUInt();
-      if (size>5 && size<20)
+      if (size > 5 && size < 20)
       {
         QFont f(parts.join(" "), size);
         QApplication::setFont(f);
@@ -155,7 +157,7 @@ void Style::polish(QWidget *widget)
   */
   if (qobject_cast<QAbstractButton*>(widget)
       || qobject_cast<QAbstractSlider*>(widget)
-      || qobject_cast<QAbstractItemView*>(getParent(widget,1))
+      || qobject_cast<QAbstractItemView*>(pw)
       || widget->inherits("QSplitterHandle")
       || widget->inherits("QHeaderView")
       || widget->inherits("QSizeGrip"))
@@ -185,11 +187,9 @@ void Style::polish(QWidget *widget)
     }
     QColor disabledCol = tColor;
     disabledCol.setAlpha(102); // 0.4 * disabledCol.alpha()
-#if (QT_VERSION >= QT_VERSION_CHECK(5,12,0))
     QColor ptColor = tColor; // placeholder
     ptColor.setAlpha(128);
     opacifyColor(ptColor);
-#endif
     opacifyColor(tColor);
     opacifyColor(inactiveCol);
     opacifyColor(disabledCol);
@@ -209,9 +209,7 @@ void Style::polish(QWidget *widget)
         palette.setColor(QPalette::Active, QPalette::Text, tColor);
         palette.setColor(QPalette::Inactive, QPalette::Text, inactiveCol);
         palette.setColor(QPalette::Disabled, QPalette::Text, disabledCol);
-#if (QT_VERSION >= QT_VERSION_CHECK(5,12,0))
         palette.setColor(QPalette::PlaceholderText, ptColor);
-#endif
         respectDarkness = false; // we don't want to change its text color again
       }
       forcePalette(widget, palette);
@@ -228,15 +226,11 @@ void Style::polish(QWidget *widget)
           palette.setColor(QPalette::Active, QPalette::Text, tColor);
           palette.setColor(QPalette::Inactive, QPalette::Text, inactiveCol);
           palette.setColor(QPalette::Disabled, QPalette::Text, disabledCol);
-#if (QT_VERSION >= QT_VERSION_CHECK(5,12,0))
           palette.setColor(QPalette::PlaceholderText, ptColor);
-#endif
           forcePalette(widget, palette);
-#if (QT_VERSION >= QT_VERSION_CHECK(5,12,0))
           /* also correct the color of the symbolic clear icon */
           if (QAction *clearAction = widget->findChild<QAction*>(QLatin1String("_q_qlineeditclearaction")))
             clearAction->setIcon(standardIcon(QStyle::SP_LineEditClearButton, nullptr, widget));
-#endif
         }
       }
     }
@@ -267,11 +261,11 @@ void Style::polish(QWidget *widget)
     { // on toolbars, labels get the button text color; that's corrected here
       QPalette palette = widget->palette();
       palette.setColor(QPalette::Active, QPalette::ButtonText,
-                      standardPalette().color(QPalette::Active,QPalette::WindowText));
+                       standardPalette().color(QPalette::Active,QPalette::WindowText));
       palette.setColor(QPalette::Inactive, QPalette::ButtonText,
-                      standardPalette().color(QPalette::Inactive,QPalette::WindowText));
+                       standardPalette().color(QPalette::Inactive,QPalette::WindowText));
       palette.setColor(QPalette::Disabled, QPalette::ButtonText,
-                      standardPalette().color(QPalette::Disabled,QPalette::WindowText));
+                       standardPalette().color(QPalette::Disabled,QPalette::WindowText));
       forcePalette(widget, palette);
       respectDarkness = false;
     }
@@ -584,7 +578,7 @@ void Style::polish(QWidget *widget)
   if (wBaseCol.alpha() < 255 && wBaseCol == standardPalette().color(QPalette::Base)
       && ((isOpaque_ && qobject_cast<QAbstractItemView*>(widget)) // like in VLC play list view
           /* Without combo menu, "QComboBoxPrivateContainer" should be opaque.
-            With combo menu, it may be changed by the app and so, polished again (like in Lyx). */
+             With combo menu, it may be changed by the app and so, polished again (like in Lyx). */
           || widget->inherits("QComboBoxPrivateContainer")
           || (!tspec_.combo_menu && widget->inherits("QComboBoxListView")) // simple combo popup
           || widget->inherits("QTextEdit") || widget->inherits("QPlainTextEdit")
@@ -664,8 +658,8 @@ void Style::polish(QWidget *widget)
     if (qobject_cast<QLineEdit*>(widget)
         && (tspec_.animate_states
             /* a workaround for bad codes that change line-edit base color */
-            || (!isPcmanfm_ && (tspec_.combo_as_lineedit || tspec_.square_combo_button)
-                && qobject_cast<QComboBox*>(pw))))
+            /*|| (!isPcmanfm_ && (tspec_.combo_as_lineedit || tspec_.square_combo_button)
+                && qobject_cast<QComboBox*>(pw))*/))
     {
       widget->installEventFilter(this);
     }
@@ -856,12 +850,27 @@ void Style::polish(QWidget *widget)
        && !widget->inherits("QTextEdit") && !widget->inherits("QPlainTextEdit")
        && !widget->inherits("KSignalPlotter"))
     {
-      QScroller::grabGesture(vp, QScroller::LeftMouseButtonGesture);
-      auto sp = QScroller::scroller(vp)->scrollerProperties();
-      sp.setScrollMetric(QScrollerProperties::OvershootScrollTime, static_cast<qreal>(0.3));
-      sp.setScrollMetric(QScrollerProperties::OvershootScrollDistanceFactor, static_cast<qreal>(0.1));
-      sp.setScrollMetric(QScrollerProperties::OvershootDragDistanceFactor, static_cast<qreal>(0.1));
-      QScroller::scroller(vp)->setScrollerProperties(sp);
+      bool insideSubwin(false);
+      QWidget *parent = pw;
+      while (parent)
+      {
+        if (qobject_cast<QMdiSubWindow*>(parent))
+        {
+          insideSubwin = true; // as in Krita
+          break;
+        }
+        if (parent->isWindow()) break;
+        parent = parent->parentWidget();
+      }
+      if(!insideSubwin)
+      {
+        QScroller::grabGesture(vp, QScroller::LeftMouseButtonGesture);
+        auto sp = QScroller::scroller(vp)->scrollerProperties();
+        sp.setScrollMetric(QScrollerProperties::OvershootScrollTime, static_cast<qreal>(0.3));
+        sp.setScrollMetric(QScrollerProperties::OvershootScrollDistanceFactor, static_cast<qreal>(0.1));
+        sp.setScrollMetric(QScrollerProperties::OvershootDragDistanceFactor, static_cast<qreal>(0.1));
+        QScroller::scroller(vp)->setScrollerProperties(sp);
+      }
     }
 #endif
     if (/*sa->frameShape() == QFrame::NoFrame &&*/ // Krita and digiKam aren't happy with this
@@ -886,11 +895,8 @@ void Style::polish(QWidget *widget)
       {
         // support animation only if the background is flat
         if ((tspec_.animate_states
-             && (!vp || vp->autoFillBackground() || (!vp->styleSheet().isEmpty()
-#if (QT_VERSION >= QT_VERSION_CHECK(5,12,0))
-                 && vp->testAttribute(Qt::WA_StyleSheetTarget)
-#endif
-                ))
+             && (!vp || vp->autoFillBackground()
+                 || (!vp->styleSheet().isEmpty() && vp->testAttribute(Qt::WA_StyleSheetTarget)))
              && themeRndr_ && themeRndr_->isValid()) // the default SVG file doesn't have a focus state for frames
            || (hasInactiveSelItemCol_
                && qobject_cast<QAbstractItemView*>(widget))) // enforce the text color of inactive selected items
@@ -901,11 +907,8 @@ void Style::polish(QWidget *widget)
         if ((tspec_.scrollbar_in_view || (widget->inherits("QComboBoxListView")
                                           && (!tspec_.combo_menu /*|| isLibreoffice_*/)))
             && vp && vp->autoFillBackground()
-            && (
-#if (QT_VERSION >= QT_VERSION_CHECK(5,12,0))
-                !vp->testAttribute(Qt::WA_StyleSheetTarget) ||
-#endif
-                vp->styleSheet().isEmpty() || !vp->styleSheet().contains("background"))
+            && (!vp->testAttribute(Qt::WA_StyleSheetTarget)
+                || vp->styleSheet().isEmpty() || !vp->styleSheet().contains(QLatin1String("background")))
             // but not when the combo popup is drawn as a menu
             && !(tspec_.combo_menu /*&& !isLibreoffice_*/ && widget->inherits("QComboBoxListView"))
             // also consider pcmanfm hacking keys
@@ -1029,24 +1032,11 @@ void Style::polish(QWidget *widget)
         widget->installEventFilter(this);
       }
 
-#if (QT_VERSION < QT_VERSION_CHECK(5,12,0))
-      if (tspec_.isX11 || widget->inherits("QTipLabel"))
-      {
-#endif
-        if (!widget->testAttribute(Qt::WA_TranslucentBackground))
-          widget->setAttribute(Qt::WA_TranslucentBackground); // Qt5 may need this too
+      if (!widget->testAttribute(Qt::WA_TranslucentBackground))
+        widget->setAttribute(Qt::WA_TranslucentBackground); // Qt5 may need this too
 #if (QT_VERSION >= QT_VERSION_CHECK(5,13,1))
-        else if (!widget->testAttribute(Qt::WA_NoSystemBackground))
-          widget->setAttribute(Qt::WA_NoSystemBackground);
-#endif
-#if (QT_VERSION < QT_VERSION_CHECK(5,12,0))
-      }
-      else
-      { // see "Kvantum.cpp" -> setSurfaceFormat() for an explanation
-        QPalette palette = widget->palette();
-        palette.setColor(widget->backgroundRole(), QColor(Qt::transparent));
-        forcePalette(widget, palette);
-      }
+      else if (!widget->testAttribute(Qt::WA_NoSystemBackground))
+        widget->setAttribute(Qt::WA_NoSystemBackground);
 #endif
 
       translucentWidgets_.insert(widget);
@@ -1331,16 +1321,21 @@ QPalette Style::standardPalette() const
   else
   {
     col = standardPalette_.color(QPalette::Active,QPalette::Base);
-    int v = col.value();
-    if (v < 127) v += 5; else v -= 5;
-    col.setHsv(col.hue(), col.saturation(), v);
+    int l = col.lightness();
+    if (l < 127) l += 10; else l -= 10;
+    col.setHsl(col.hue(), col.saturation(), l, col.alpha());
     standardPalette_.setColor(QPalette::Active,QPalette::AlternateBase,col);
-
-    col = standardPalette_.color(QPalette::Inactive,QPalette::Base);
-    v = col.value();
-    if (v < 127) v += 5; else v -= 5;
-    col.setHsv(col.hue(), col.saturation(), v);
-    standardPalette_.setColor(QPalette::Inactive,QPalette::AlternateBase,col);
+    standardPalette_.setColor(QPalette::Disabled,QPalette::AlternateBase,col);
+    if (!hasInactiveness)
+      standardPalette_.setColor(QPalette::Inactive,QPalette::AlternateBase,col);
+    else
+    {
+      col = standardPalette_.color(QPalette::Inactive,QPalette::Base);
+      l = col.lightness();
+      if (l < 127) l += 10; else l -= 10;
+      col.setHsl(col.hue(), col.saturation(), l, col.alpha());
+      standardPalette_.setColor(QPalette::Inactive,QPalette::AlternateBase,col);
+    }
   }
 
   col = getFromRGBA(cspec_.buttonColor);
@@ -1402,24 +1397,18 @@ QPalette Style::standardPalette() const
   col = getFromRGBA(cspec_.textColor);
   if (col.isValid())
   {
-#if (QT_VERSION >= QT_VERSION_CHECK(5,12,0))
     QColor placeholderTextColor = col;
     placeholderTextColor.setAlpha(128);
-#endif
     if (hspec_.opaque_colors)
     { // if opaqueness is forced, apply it over the base color
       QColor baseCol = standardPalette_.color(QPalette::Active,QPalette::Base);
       baseCol.setAlpha(255);
       if (col.alpha() < 255)
         col = overlayColor(baseCol,col);
-#if (QT_VERSION >= QT_VERSION_CHECK(5,12,0))
       placeholderTextColor = overlayColor(baseCol,placeholderTextColor);
-#endif
     }
     standardPalette_.setColor(QPalette::Active,QPalette::Text,col);
-#if (QT_VERSION >= QT_VERSION_CHECK(5,12,0))
     standardPalette_.setColor(QPalette::PlaceholderText,placeholderTextColor);
-#endif
     col1 = getFromRGBA(cspec_.inactiveTextColor);
     if (col1.isValid() && hasInactiveness)
     {
