@@ -19,17 +19,14 @@
 #define SPEC_H
 
 #include <QStringList>
-#if (QT_VERSION >= QT_VERSION_CHECK(5,0,0))
 #if (QT_VERSION >= QT_VERSION_CHECK(5,15,0))
 #include "drag/windowmanager.h"
 #else
 #include "drag/windowmanager-old.h"
 #endif
-#else
-#include "qt4/windowmanager4.h"
-#endif
 
 namespace Kvantum {
+
 /* Generic information about a theme */
 typedef struct {
   QString author;
@@ -53,6 +50,8 @@ typedef struct {
   bool left_tabs;
   /* always center tabs in the document mode? */
   bool center_doc_tabs;
+  /* always center normal tabs? */
+  bool center_normal_tabs;
   /* join inactive tabs together?
      (by default, they are joined) */
   bool joined_inactive_tabs;
@@ -281,8 +280,6 @@ typedef struct {
   bool transparent_ktitle_label;
   /* transparent background for (KDE) menu titles */
   bool transparent_menutitle;
-  /* draw KCapacityBars as progressbars? */
-  bool kcapacitybar_as_progressbar;
   /* Some apps don't respect dark themes.
      Fix that as far as possible! */
   bool respect_darkness;
@@ -306,6 +303,8 @@ typedef struct {
   bool iconless_menu;
   /* only style the top toolbar? */
   bool single_top_toolbar;
+  /* style vertical toolbars? */
+  bool style_vertical_toolbars;
   /* should the scroll jump be done by middle clicking?
      (By default, it's done by left clicking.) */
   bool middle_click_scroll;
@@ -472,6 +471,7 @@ static inline void default_theme_spec(theme_spec &tspec) {
   tspec.click_behavior = 0;
   tspec.left_tabs = false;
   tspec.center_doc_tabs = false;
+  tspec.center_normal_tabs = false;
   tspec.joined_inactive_tabs = true;
   tspec.attach_active_tab = false;
   tspec.embedded_tabs = false;
@@ -485,7 +485,7 @@ static inline void default_theme_spec(theme_spec &tspec) {
   tspec.group_toolbar_buttons = false;
   tspec.toolbar_item_spacing = 0;
   tspec.toolbar_interior_spacing = 0;
-  tspec.toolbar_separator_thickness = 0;
+  tspec.toolbar_separator_thickness = -1;
   tspec.center_toolbar_handle = false;
   tspec.slim_toolbars = false;
   tspec.merge_menubar_with_toolbar = false;
@@ -566,7 +566,6 @@ static inline void default_hacks_spec(hacks_spec &hspec) {
   hspec.opaque_colors = false;
   hspec.transparent_ktitle_label = false;
   hspec.transparent_menutitle = false;
-  hspec.kcapacitybar_as_progressbar = true;
   hspec.respect_darkness = false;
   hspec.forceSizeGrip = false;
   hspec.tint_on_mouseover = 0;
@@ -577,11 +576,13 @@ static inline void default_hacks_spec(hacks_spec &hspec) {
   hspec.transparent_arrow_button=false;
   hspec.iconless_menu = false;
   hspec.single_top_toolbar = false;
+  hspec.style_vertical_toolbars = false;
   hspec.middle_click_scroll = false;
   hspec.centered_forms = false;
   hspec.kinetic_scrolling = false;
   hspec.noninteger_translucency = false;
 }
+
 }
 
 #endif
